doc

package
v0.32.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCmdCreate

func NewCmdCreate(f *cmdutil.Factory) *cobra.Command

NewCmdCreate returns a command to create a new ClickUp Doc.

func NewCmdDoc

func NewCmdDoc(f *cmdutil.Factory) *cobra.Command

NewCmdDoc returns the top-level "doc" command that groups Docs subcommands.

func NewCmdList

func NewCmdList(f *cmdutil.Factory) *cobra.Command

NewCmdList returns a command to list ClickUp Docs in the workspace.

func NewCmdPage

func NewCmdPage(f *cmdutil.Factory) *cobra.Command

NewCmdPage returns the "doc page" subcommand group.

func NewCmdPageCreate

func NewCmdPageCreate(f *cmdutil.Factory) *cobra.Command

NewCmdPageCreate returns a command to create a page within a ClickUp Doc.

func NewCmdPageEdit

func NewCmdPageEdit(f *cmdutil.Factory) *cobra.Command

NewCmdPageEdit returns a command to edit an existing page in a ClickUp Doc.

func NewCmdPageList

func NewCmdPageList(f *cmdutil.Factory) *cobra.Command

NewCmdPageList returns a command to list pages in a ClickUp Doc.

func NewCmdPageView

func NewCmdPageView(f *cmdutil.Factory) *cobra.Command

NewCmdPageView returns a command to view a single page in a ClickUp Doc.

func NewCmdView

func NewCmdView(f *cmdutil.Factory) *cobra.Command

NewCmdView returns a command to view a single ClickUp Doc.

Types

This section is empty.

Jump to