task

package
v0.32.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCmdActivity added in v0.2.0

func NewCmdActivity(f *cmdutil.Factory) *cobra.Command

NewCmdActivity returns a command to view a task's details and comment history.

func NewCmdChecklist added in v0.4.0

func NewCmdChecklist(f *cmdutil.Factory) *cobra.Command

NewCmdChecklist returns the "task checklist" parent command.

func NewCmdCreate

func NewCmdCreate(f *cmdutil.Factory) *cobra.Command

NewCmdCreate returns a command to create a new ClickUp task.

func NewCmdDelete added in v0.10.0

func NewCmdDelete(f *cmdutil.Factory) *cobra.Command

NewCmdDelete returns a command to delete a ClickUp task.

func NewCmdDependency added in v0.4.0

func NewCmdDependency(f *cmdutil.Factory) *cobra.Command

NewCmdDependency returns the "task dependency" parent command.

func NewCmdEdit

func NewCmdEdit(f *cmdutil.Factory) *cobra.Command

NewCmdEdit returns a command to edit an existing ClickUp task.

func NewCmdList

func NewCmdList(f *cmdutil.Factory) *cobra.Command

NewCmdList returns a command to list ClickUp tasks in a given list.

func NewCmdListAdd added in v0.12.0

func NewCmdListAdd(f *cmdutil.Factory) *cobra.Command

NewCmdListAdd returns a command to add tasks to an additional list.

func NewCmdListRemove added in v0.12.0

func NewCmdListRemove(f *cmdutil.Factory) *cobra.Command

NewCmdListRemove returns a command to remove tasks from an additional list.

func NewCmdMove added in v0.32.0

func NewCmdMove(f *cmdutil.Factory) *cobra.Command

NewCmdMove returns a command to move a task to a different list.

func NewCmdRecent added in v0.5.0

func NewCmdRecent(f *cmdutil.Factory) *cobra.Command

NewCmdRecent returns a command to show recently updated tasks.

func NewCmdSearch added in v0.2.0

func NewCmdSearch(f *cmdutil.Factory) *cobra.Command

NewCmdSearch returns a command to search ClickUp tasks by name.

func NewCmdTask

func NewCmdTask(f *cmdutil.Factory) *cobra.Command

NewCmdTask returns the top-level "task" command that groups view, list, create, and edit.

func NewCmdTime added in v0.3.0

func NewCmdTime(f *cmdutil.Factory) *cobra.Command

NewCmdTime returns the parent command for time tracking subcommands.

func NewCmdTimeDelete added in v0.10.0

func NewCmdTimeDelete(f *cmdutil.Factory) *cobra.Command

NewCmdTimeDelete returns a command to delete a time entry.

func NewCmdTimeList added in v0.3.0

func NewCmdTimeList(f *cmdutil.Factory) *cobra.Command

NewCmdTimeList returns a command to list time entries for a task or date range.

func NewCmdTimeLog added in v0.3.0

func NewCmdTimeLog(f *cmdutil.Factory) *cobra.Command

NewCmdTimeLog returns a command to log a time entry on a task.

func NewCmdTimeRunning added in v0.32.0

func NewCmdTimeRunning(f *cmdutil.Factory) *cobra.Command

NewCmdTimeRunning returns a command to show the current running timer.

func NewCmdTimeStart added in v0.32.0

func NewCmdTimeStart(f *cmdutil.Factory) *cobra.Command

NewCmdTimeStart returns a command to start a time entry timer.

func NewCmdTimeStop added in v0.32.0

func NewCmdTimeStop(f *cmdutil.Factory) *cobra.Command

NewCmdTimeStop returns a command to stop the running time entry timer.

func NewCmdView

func NewCmdView(f *cmdutil.Factory) *cobra.Command

NewCmdView returns a command to view one or more ClickUp tasks.

Types

This section is empty.

Jump to