Documentation
¶
Index ¶
- func NewCmdCreate(f *cmdutil.Factory) *cobra.Command
- func NewCmdDoc(f *cmdutil.Factory) *cobra.Command
- func NewCmdList(f *cmdutil.Factory) *cobra.Command
- func NewCmdPage(f *cmdutil.Factory) *cobra.Command
- func NewCmdPageCreate(f *cmdutil.Factory) *cobra.Command
- func NewCmdPageEdit(f *cmdutil.Factory) *cobra.Command
- func NewCmdPageList(f *cmdutil.Factory) *cobra.Command
- func NewCmdPageView(f *cmdutil.Factory) *cobra.Command
- func NewCmdView(f *cmdutil.Factory) *cobra.Command
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdCreate ¶
NewCmdCreate returns a command to create a new ClickUp Doc.
func NewCmdList ¶
NewCmdList returns a command to list ClickUp Docs in the workspace.
func NewCmdPage ¶
NewCmdPage returns the "doc page" subcommand group.
func NewCmdPageCreate ¶
NewCmdPageCreate returns a command to create a page within a ClickUp Doc.
func NewCmdPageEdit ¶
NewCmdPageEdit returns a command to edit an existing page in a ClickUp Doc.
func NewCmdPageList ¶
NewCmdPageList returns a command to list pages in a ClickUp Doc.
func NewCmdPageView ¶
NewCmdPageView returns a command to view a single page in a ClickUp Doc.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.