Documentation
¶
Index ¶
- func NewCmdActivity(f *cmdutil.Factory) *cobra.Command
- func NewCmdChecklist(f *cmdutil.Factory) *cobra.Command
- func NewCmdCreate(f *cmdutil.Factory) *cobra.Command
- func NewCmdDelete(f *cmdutil.Factory) *cobra.Command
- func NewCmdDependency(f *cmdutil.Factory) *cobra.Command
- func NewCmdEdit(f *cmdutil.Factory) *cobra.Command
- func NewCmdList(f *cmdutil.Factory) *cobra.Command
- func NewCmdListAdd(f *cmdutil.Factory) *cobra.Command
- func NewCmdListRemove(f *cmdutil.Factory) *cobra.Command
- func NewCmdMove(f *cmdutil.Factory) *cobra.Command
- func NewCmdRecent(f *cmdutil.Factory) *cobra.Command
- func NewCmdSearch(f *cmdutil.Factory) *cobra.Command
- func NewCmdTask(f *cmdutil.Factory) *cobra.Command
- func NewCmdTime(f *cmdutil.Factory) *cobra.Command
- func NewCmdTimeDelete(f *cmdutil.Factory) *cobra.Command
- func NewCmdTimeList(f *cmdutil.Factory) *cobra.Command
- func NewCmdTimeLog(f *cmdutil.Factory) *cobra.Command
- func NewCmdTimeRunning(f *cmdutil.Factory) *cobra.Command
- func NewCmdTimeStart(f *cmdutil.Factory) *cobra.Command
- func NewCmdTimeStop(f *cmdutil.Factory) *cobra.Command
- func NewCmdView(f *cmdutil.Factory) *cobra.Command
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdActivity ¶ added in v0.2.0
NewCmdActivity returns a command to view a task's details and comment history.
func NewCmdChecklist ¶ added in v0.4.0
NewCmdChecklist returns the "task checklist" parent command.
func NewCmdCreate ¶
NewCmdCreate returns a command to create a new ClickUp task.
func NewCmdDelete ¶ added in v0.10.0
NewCmdDelete returns a command to delete a ClickUp task.
func NewCmdDependency ¶ added in v0.4.0
NewCmdDependency returns the "task dependency" parent command.
func NewCmdEdit ¶
NewCmdEdit returns a command to edit an existing ClickUp task.
func NewCmdList ¶
NewCmdList returns a command to list ClickUp tasks in a given list.
func NewCmdListAdd ¶ added in v0.12.0
NewCmdListAdd returns a command to add tasks to an additional list.
func NewCmdListRemove ¶ added in v0.12.0
NewCmdListRemove returns a command to remove tasks from an additional list.
func NewCmdMove ¶ added in v0.32.0
NewCmdMove returns a command to move a task to a different list.
func NewCmdRecent ¶ added in v0.5.0
NewCmdRecent returns a command to show recently updated tasks.
func NewCmdSearch ¶ added in v0.2.0
NewCmdSearch returns a command to search ClickUp tasks by name.
func NewCmdTask ¶
NewCmdTask returns the top-level "task" command that groups view, list, create, and edit.
func NewCmdTime ¶ added in v0.3.0
NewCmdTime returns the parent command for time tracking subcommands.
func NewCmdTimeDelete ¶ added in v0.10.0
NewCmdTimeDelete returns a command to delete a time entry.
func NewCmdTimeList ¶ added in v0.3.0
NewCmdTimeList returns a command to list time entries for a task or date range.
func NewCmdTimeLog ¶ added in v0.3.0
NewCmdTimeLog returns a command to log a time entry on a task.
func NewCmdTimeRunning ¶ added in v0.32.0
NewCmdTimeRunning returns a command to show the current running timer.
func NewCmdTimeStart ¶ added in v0.32.0
NewCmdTimeStart returns a command to start a time entry timer.
func NewCmdTimeStop ¶ added in v0.32.0
NewCmdTimeStop returns a command to stop the running time entry timer.
Types ¶
This section is empty.